const rl = @import("raylib.zig");
const std = @import("std");
const config = @import("Config/config.zig");

pub const Input = struct {
    name: []const u8,
    code: i32,
    default: i32,

    pub fn isDown(self: Input) bool {
        return rl.isKeyDown(self.code);
    }
    pub fn isJustPressed(self: Input) bool {
        return rl.isKeyPressed(self.code);
    }
    pub fn isJustReleased(self: Input) bool {
        return rl.isKeyReleased(self.code);
    }
};

fn init(comptime name: []const u8, comptime key_code: []const u8) Input {
    return Input{
        .name = name,
        .code = rl.getKeyCode(key_code),
        .default = rl.getKeyCode(key_code),
    };
}

pub fn loadConfig() void {
    var configIterator = config.getConfigIterator("input.ini") catch {
        // Error opening config
        std.debug.print("Cannot load input.ini configuration file, using default keybindings\n");
        return;
    };

    // while (configIterator.next()) |option| {

    // }
    configIterator.deinit();

}

pub var menu_right = init("Menu Right", "RIGHT");
pub var menu_left = init("Menu Left", "LEFT");
pub var menu_down = init("Menu Down", "DOWN");
pub var menu_up = init("Menu Up", "UP");
pub var menu_accept = init("Menu Accept", "ENTER");
pub var menu_cancel = init("Menu Cancel", "BACKSPACE");

pub var game_right = init("Move Right", "D");
pub var game_left = init("Move Left", "A");
pub var game_down = init("Move Down", "S");
pub var game_drop = init("Drop Piece", "W");
pub var game_swap_piece = init("Swap Piece", "SPACE");
pub var game_rotate_r = init("Rotate Piece Clockwise", "RIGHT");
pub var game_rotate_l = init("Rotate Piece Counterclockwise", "LEFT");
